@@ -158,22 +158,28 @@ static void area_main_update(context_t *context) {
 
   /* also setup the local error messages here, so they are */
   /* updated for all entries at once */
-  if(context->min.lat >= context->max.lat ||
-     context->min.lon >= context->max.lon) {
-    gtk_label_set(GTK_LABEL(context->direct.error), 
-		  _("\"From\" must be smaller than \"to\" value!")); 
-    gtk_label_set(GTK_LABEL(context->extent.error), 
-		  _("Extents must be positive!")); 
-
+  if(isnan(context->min.lat) || isnan(context->min.lon) ||
+     isnan(context->min.lat) || isnan(context->min.lon)) {
     gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
 				      GTK_RESPONSE_ACCEPT, FALSE);
-
   } else {
-    gtk_label_set(GTK_LABEL(context->direct.error), "");
-    gtk_label_set(GTK_LABEL(context->extent.error), "");
+    if(context->min.lat >= context->max.lat ||
+       context->min.lon >= context->max.lon) {
+      gtk_label_set(GTK_LABEL(context->direct.error), 
+		  _("\"From\" must be smaller than \"to\" value!")); 
+      gtk_label_set(GTK_LABEL(context->extent.error), 
+		  _("Extents must be positive!"));
+      gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
+				      GTK_RESPONSE_ACCEPT, FALSE);
+    } 
+    else
+    {
+      gtk_label_set(GTK_LABEL(context->direct.error), "");
+      gtk_label_set(GTK_LABEL(context->extent.error), "");
 
-    gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
+      gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
 				      GTK_RESPONSE_ACCEPT, TRUE);
+    }
   }
 
   /* check if area size exceeds recommended values */
@@ -432,7 +438,7 @@ on_map_button_press_event(GtkWidget *widget,
   osm_gps_map_osd_t *osd = osm_gps_map_osd_get(map);
 
   /* osm-gps-map needs this event to handle the OSD */
-  if(osd->check(osd, (int)event->x, (int)event->y))
+  if(osd->check(osd, TRUE, (int)event->x, (int)event->y))
     return FALSE;
 
   /* remove existing marker */
@@ -516,21 +522,12 @@ on_map_button_release_event(GtkWidget *widget,
   }
 
   /* osm-gps-map needs this event to handle the OSD */
-  if(osd->check(osd, (int)event->x, (int)event->y))
+  if(osd->check(osd, TRUE, (int)event->x, (int)event->y))
     return FALSE;
 
   return TRUE;
 }
 
-#if 0
-static void map_zoom(context_t *context, int step) {
-  int zoom;
-  OsmGpsMap *map = OSM_GPS_MAP(context->map.widget);
-  g_object_get(map, "zoom", &zoom, NULL);
-  zoom = osm_gps_map_set_zoom(map, zoom+step);
-}
-#endif
-
 static void
 cb_map_gps(osd_button_t but, context_t *context) {
   if(but == OSD_GPS) {
