@@ -22,7 +22,8 @@
 
 #include "project.h"
 
-gboolean osm_download(GtkWidget *parent, project_t *project);
+gboolean osm_download(GtkWidget *parent, settings_t *settings,
+		      project_t *project);
 void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project);
 
 #endif // OSM_API_H
